@@ -4,6 +4,19 @@ import slack
 import contextlib
 import warnings
 from typing import Union, List
+from logging import StreamHandler, LogRecord, Formatter
+
+
+# some predefined formatters for convenience
+# detailed message with time, name, level, and message
+DETAILED_FORMATTER = Formatter(
+    '`%(asctime)s` `%(name)s` *%(levelname)s*: %(message)s'
+)
+
+# timestamped message
+TIMESTAMPED_FORMATTER = Formatter(
+    '`%(asctime)s` %(message)s'
+)
 
 # retrieve tokens and names from environment variables if defined
 DEFAULT_CHANNEL_NAME: str = os.getenv('slackchannel')
@@ -21,13 +34,18 @@ else:
 BOT_LIST = []
 
 
-class SlackBot(object):
+class SlackBot(StreamHandler):
+    # default formatter
+    DEFAULT_FORMATTER = TIMESTAMPED_FORMATTER
+
     def __init__(self,
                  user_member_ids: Union[str, List[str]] = None,
                  user_member_id: str = None,
                  token: str = BOT_TOKEN,
                  channel_name: str = None,
                  bot_name: str = None,
+                 alert_level: int = 30,
+                 formatter: Formatter = None,
                  ):
         """
         A basic Slack bot that will message users and channels
@@ -37,7 +55,14 @@ class SlackBot(object):
             ID: ABCDEF.
         :param str token: token to connect to slack client
         :param str channel_name: channel to message on. for example, #channelname
+        :param alert_level: alert level to notify the defined user at
+        :param formatter: logging formatter to use (if not specified, the class DEFAULT_FORMATTER is used)
         """
+        StreamHandler.__init__(self)
+        if formatter is None:
+            formatter = self.DEFAULT_FORMATTER
+        self.setFormatter(formatter)
+        self.alert_level = alert_level
         self._target_users: List[str] = []
         self._channel = DEFAULT_CHANNEL_NAME
         self._bot_token = BOT_TOKEN
@@ -194,6 +219,17 @@ class SlackBot(object):
     def bot_token(self):
         self._bot_token = BOT_TOKEN
 
+    def emit(self, record: LogRecord) -> None:
+        """function required for logging StreamHandling, not intended for direct interaction"""
+        # catch and format message
+        msg = self.format(record)
+        # determine whether to tag admin
+        tag_admin = True if record.levelno >= self.alert_level else False
+        self.post_slack_message(
+            msg,
+            tag_admin=tag_admin,
+        )
+
     def post_slack_message(self,
                            msg: str,
                            tag_admin: bool = False,
@@ -475,6 +511,8 @@ class RTMSlackBot(SlackBot):
                  channel_name: str = None,
                  auto_reconnect: bool = True,
                  ping_interval: int = 10,
+                 alert_level: int = 30,
+                 formatter: Formatter = None,
                  **kwargs
                  ):
         """
@@ -488,6 +526,8 @@ class RTMSlackBot(SlackBot):
         :param str channel_name: channel to message on. for example, #channelname
         :param auto_reconnect: enable/disable RTM auto-reconnect
         :param ping_interval: ping interval for RTM client
+        :param alert_level: alert level to notify the defined user at
+        :param formatter: logging formatter to use (if not specified, the class DEFAULT_FORMATTER is used)
         """
         self._temp_client: slack.WebClient = None
         self.rtm_client: slack.RTMClient = slack.RTMClient(
@@ -508,6 +548,8 @@ class RTMSlackBot(SlackBot):
             user_member_ids=user_member_ids,
             token=token,
             channel_name=channel_name,
+            alert_level=alert_level,
+            formatter=formatter,
             **kwargs,
         )
 
